<?php

namespace Supportingcast\Shortcodes;

use Supportingcast\ScUser;

class Content extends Template
{
	private $feeds;
	private $slug;

	public function handle()
	{

		$this->slug = get_query_var('podcast');

		try {
			$user = new ScUser(wp_get_current_user());
			$user->getOrCreate();
			$this->feeds = $user->getFeeds();
		} catch (\Exception $e) {
			$msg = 'Sorry, something went wrong. Please try again later.';
			if (defined('WP_DEBUG') && WP_DEBUG) {
				$msg = $e->getMessage();
			}

			return (new Error(['msg' => $msg]))->handle();
		}

		if (empty($this->feeds)) {
			return (new Error(['msg' => 'Sorry, we couldn\'t find any podcast feeds.']))->handle();
		}

		if (!$this->slug && count($this->feeds) > 1) {
			return (new FeedList(['feeds' => $this->feeds]))->handle();
		}

		$feed = $this->getFeed();

		if ( ! $feed) {
			return (new Error(['msg' => 'Sorry, we could not find that podcast feed.']))->handle();
		}

		return do_shortcode((new FeedDetail(['feed' => $feed, 'user' => $user]))->handle());
	}

	private function getFeed(): ?object
	{
		if ( ! $this->slug) {
			return $this->feeds[0] ?? null;
		}

		foreach ($this->feeds as $feed_from_collection) {
			if ($feed_from_collection->slug === $this->slug) {
				return $feed_from_collection;
			}
		}

		return null;
	}
}
