<?php
namespace Supportingcast\Woocommere;

use Supportingcast\Api;
use Supportingcast\ScProducts;
use Supportingcast\WPUserInterpreter;

SyncTool::boot();

class SyncTool
{
	const META_PRODUCT_ID = 'supportingcast_product_id';


    public static function boot()
    {
        $syncTool = new SyncTool();

        if ('wordpress' != get_option('sc-member-source')) {
        	return;
        }

	    add_action('admin_menu', [$syncTool, 'sync_tool_menu'], 11);
	    add_action('wp_ajax_sc_sync_tool', [$syncTool, 'sync_tool_run']);

    }

	function sync_tool_menu() {
		add_submenu_page(
			'tools.php', // top level menu page
			'Supporting Cast', // title of the settings page
			'Supporting Cast', // title of the submenu
			'manage_options', // capability of the user to see this page
			'supporting-cast', // slug of the settings page
			[$this, 'sync_tool_html'] // callback function when rendering the page
		);
	}

	function sync_tool_html() {

		wp_enqueue_script(
			'sc-sync-tool-js',
			plugins_url('', __FILE__) . '/../../js/sc-sync-tool.js',
			[],
			SUPPORTING_CAST_VERSION,
			false
		);

		$users = get_users();
		$count = count( $users );

		include( __DIR__ . '/../../views/SyncTool.php' );

	}
	function sync_tool_run() {

		$users = get_users(['orderby' => 'ID ASC']);
		$count = count($users);

		$start = $_POST['sync_start'];
		$limit = $_POST['sync_limit'];

		$end = $start + $limit;
		if ($end > $count) {
			$end = $count;
		}

		$batch = [];
		for ($i = $start; $i < $end; $i++) {
			$user = $users[$i];

			$wpUserInterpreter = new WPUserInterpreter($user, 'wordpress');

			$batch["{$user->ID}@{$i}"] = [
				"path" => "/v1/memberships/sync",
				"method" => "post",
			    "data" => [
					'external_id' => $wpUserInterpreter->getScExternalId(),
					'plan_id'     => $wpUserInterpreter->getScPlanId(),
					'product_ids' => $wpUserInterpreter->getScProductIds(),
				]
			];
		}

		$api = new Api();
		$api->post('bulk', $batch);

		$headers = [
			"x-batch-ratelimit-limit",
			"x-batch-ratelimit-remaining",
			"x-ratelimit-remaining",
			"retry-after",
		];

		$responseHeaders = $api->getResponse()->headers;
		foreach ($headers as $header) {
			if (isset($responseHeaders[$header])) {
				header($header . ': '. $responseHeaders[$header], true);
			}
		}

		wp_die(
			$api->getResponse()->body,
			'',
			[
				'response' => $api->getResponse()->status_code > 0 ? $api->getResponse()->status_code : 500,
		]);

    }
}