<?php
namespace Supportingcast\Woocommere;

use Supportingcast\DuplicatePurchaseException;
use Supportingcast\ScProducts;
use Supportingcast\ScUser;

ProcessOrder::boot();

class ProcessOrder
{

	const DEFAULT_STATUS_ACCESS = [
		'wc-pending' => 0,
		'wc-processing' => 1,
		'wc-on-hold' => 0,
		'wc-completed' => 1,
		'wc-cancelled' => 0,
		'wc-refunded' => 0,
		'wc-failed' => 0,
	];

    public static function boot()
    {
        $processOrder = new ProcessOrder();

        add_action( 'woocommerce_order_status_changed', [ $processOrder, 'orderStatusChanged' ] );

    }

    public function orderStatusChanged($orderId, $from = null, $to = null) {

    	$fromAccess = self::getAccessForStatus($from);
    	$toAccess = self::getAccessForStatus($to);

    	if ($toAccess && ($fromAccess == $toAccess)) {
    		return;
	    }

		$order = wc_get_order($orderId);
		$products = self::getScProductIdsFromOrder($order);

	    if (count($products) > 0) {

		    if (!$order->get_user()) {
			    error_log("Supporting Cast Wordpress) WARNING- this order has no user.  Changing access to SC content requires a User");
			    return;
		    }
		    $scUser = new ScUser( $order->get_user() );
		    $scUser->sync();
	    }
    }

    public static function getScProductIdsFromOrder(\WC_Order $order): array
    {
    	if (self::getAccessForStatus($order->get_status()) == 0) {
    		return [];
	    }
    	$productIDs = [];
	    foreach ($order->get_items() as $item) {
		    $itemData = $item->get_data();
		    $scProductID = get_post_meta($itemData['product_id'], AdminProductData::META_PRODUCT_ID, true);
		    if ($scProductID) {
			   $productIDs["{$scProductID}"] = ['woocommerce_order_id' => $order->get_id()];
		    }
	    }
	    return $productIDs;
    }

    public static function getAccessForStatus($status) {
	    $statusMap = get_option('sc-woocommerce-order-status-access', \Supportingcast\Woocommere\ProcessOrder::DEFAULT_STATUS_ACCESS);
	    if (isset($statusMap[$status])) {
	    	return $statusMap[$status];
	    }

	    if (isset($statusMap['wc-'. $status])) {
		    return $statusMap['wc-'. $status];
	    }

	    return false;
    }
}